AAFeeMode class

Constructors

AAFeeMode.fromJson(Map<String, dynamic> json)
AAFeeMode.gasless(dynamic wholeFeeQuote)
gasless There are two use cases. pass null as wholeFeeQuote, to send a gasless transaction. specify wholeFeeQuote, that you can get from particle_aa rpcGetFeeQuotes, to send a gasless transaction
AAFeeMode.native(dynamic wholeFeeQuote)
select native for fee There are two use cases. pass null as wholeFeeQuote, to send a user paid transaction, use native as gas fee. specify wholeFeeQuote, that you can get from particle_aa rpcGetFeeQuotes, to send a user paid transaction, use native as gas fee.
AAFeeMode.token(dynamic feeQuote, String? tokenPaymasterAddress)
select token for fee specify feeQuote and tokenPaymasterAddress, that you can get from particle_aa rpcGetFeeQuotes, to send a user paid transaction, use token as gas fee.

Properties

feeQuote → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
option → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenPaymasterAddress → String?
final
wholeFeeQuote → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited