LoginPageConfig class

Constructors

LoginPageConfig(String imagePath, String projectName, String description)

Properties

description ↔ String
Project welcome description
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imagePath ↔ String
Support both icon url and base64 string.
getter/setter pair
projectName ↔ String
Project name
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited