SecurityAccountConfig class

Constructors

SecurityAccountConfig(int promptSettingWhenSign, int promptMasterPasswordSettingWhenLogin)
Security account config

Properties

hashCode → int
The hash code for this object.
no setterinherited
promptMasterPasswordSettingWhenLogin ↔ int
If show master password prompt when login, default value is 0. 0 no prompt 1 first time show prompt 2 every time show prompt 3 force to set master password default value is 1
getter/setter pair
promptSettingWhenSign ↔ int
if show set payment password prompt when sign, default value is 1. 0 don't show prompt when sign. 1 show prompt when first sign only. 2 show prompt when sign every time. 3 force set payment password when sign
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited