SerializeSOLTransaction class

Annotations
  • @JsonSerializable.new()

Constructors

SerializeSOLTransaction()
SerializeSOLTransaction.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lamports ↔ int
Transfer amount in minimal unit
getter/setter pair
receiver ↔ String
Receiver address
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender ↔ String
Sender address
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited